@@ -56,10 +56,10 @@ def capitalize(name):
 def get_args_parser():
     from yqn_cli import __version__
     parser = argparse.ArgumentParser(description='create module base on yqn pytorch framework')
-    parser.add_argument('-version', action='version', version='%(prog)s ' + __version__)
-    parser.add_argument('-name', type=str, default='*', help='module name exp: "key_attention"')
-    parser.add_argument('-out', type=str, default='./', help='file output path')
-    parser.add_argument('-author', type=str, default='yqn', help='author')
+    parser.add_argument('-v', '--version', action='version', version='%(prog)s ' + __version__)
+    parser.add_argument('-n', '--name', type=str, default='*', help='module name exp: "key_attention"')
+    parser.add_argument('-o', '--out', type=str, default='./', help='file output path')
+    parser.add_argument('-a', '--author', type=str, default='yqn', help='author')
     return parser
 
 
