@@ -1,8 +1,10 @@
 import torch
 
+from yqn_pytorch_framework.device import tensor_load_device
+
 
 def pytorch_to_onnx(model, device, pth_path, save_path, dummy_inputs, input_names, output_names):
-    model.to(device)
+    model = tensor_load_device(model, device).eval()
     checkpoint = torch.load(pth_path, map_location=device)
     model.load_state_dict(checkpoint['state_dict'])
     model.eval()
