@@ -5,7 +5,7 @@ import torch
 import numpy as np
 from yqn_config.base_config import BaseConfig
 from yqn_exception.exception import InputSizeException, InferModelException
-from yqn_pytorch_framework.device import get_device
+from yqn_pytorch_framework.device import get_device, tensor_load_device
 from yqn_pytorch_framework.train.base_engine import BaseModelEngine
 
 
@@ -14,11 +14,11 @@ class BaseModelInfer:
         self.config = model_config
         self.device = model_config.device
         with torch.no_grad():
-            self.model = self.load_model().to(self.device)
+            self.model = self.load_model().cpu()
             resume_file = self.get_infer_model_file()
             if os.path.exists(resume_file):
                 print("=> loading checkpoint '{}'".format(resume_file))
-                checkpoint = torch.load(resume_file, map_location=self.device)
+                checkpoint = torch.load(resume_file, map_location=torch.device('cpu'))
                 if hasattr(self.config, "saved_state"):
                     if self.config.saved_state:
                         self.model.load_state_dict(checkpoint, strict=False)
@@ -27,6 +27,8 @@ class BaseModelInfer:
                 else:
                     self.model.load_state_dict(checkpoint['state_dict'])
 
+                self.model = tensor_load_device(self.model, self.device)
+
                 self.model.eval()
                 print("=> loaded checkpoint '{}' ".format(resume_file))
             else:
@@ -88,12 +90,13 @@ class BaseModelInfer:
                     for input_items in input_features_handled:
                         input_converted = input_items[
                                           index * per_size: min(input_shape[0], (index + 1) * per_size), ]
-                        input_tensor = torch.from_numpy(np.array(input_converted)).to(self.config.device)
+                        input_tensor = tensor_load_device(torch.from_numpy(np.array(input_converted)),
+                                                          self.config.device)
                         input_tensors.append(input_tensor)
                 else:
                     input_converted = input_features_handled[
                                       index * per_size: min(input_shape[0], (index + 1) * per_size), ]
-                    input_tensors = torch.from_numpy(np.array(input_converted)).to(self.config.device)
+                    input_tensors = tensor_load_device(torch.from_numpy(np.array(input_converted)), self.config.device)
                 result = self.model(*tuple(input_tensors))
                 if type(result) is list or type(result) is tuple:
                     if index == 0:
