@@ -9,6 +9,7 @@ from torch.utils.tensorboard import SummaryWriter
 from torch import optim
 
 from yqn_config.base_config import BaseConfig
+from yqn_pytorch_framework.device import get_cpu_device, tensor_load_device
 from yqn_pytorch_framework.train.base_engine import BaseModelEngine
 
 
@@ -72,7 +73,7 @@ class BaseModelTrain:
                                   # num_workers=8,
                                   pin_memory=True)
         writer = SummaryWriter(config.get_train_log_dir())
-        model.to(config.device)
+        model = tensor_load_device(model, config.device)
         dummy_input = model.get_default_input()
         writer.add_graph(model, input_to_model=dummy_input)
         writer.flush()
@@ -117,6 +118,6 @@ class BaseModelTrain:
 
     def train(self, config):
         model = self.load_model(model_config=config)
-        model = model.to(config.device)
+        model = tensor_load_device(model, config.device)
         print(model)
         self.start_train(model, config)
